# Let's develop peasant computing, let's breed “kittens”

## Introduction

In recent years, we have witnessed the widespread concentration of internet
practices among a very limited number of online service providers, represented
by what is now known as GAFAM (Google Apple Facebook Amazon Microsoft).  This
centralisation, which is totally contradictory to the origins of the Internet,
which was conceived as decentralised and distributed [^1], led Tim Berners
Lee, the creator of the web, to formulate proposals for the future [^2].  So,
why should we be concerned about this?  Simply because data, and particularly
our personal data, are the economic fuel of these major actors, and such an
accumulation of information about us gives them immense power, turning us into
“products” thanks to their “free” services.  The questions this raises are
many and complex: generalised surveillance, artificial intelligences fed by
“*big data”*, the end of anonymity and private life, brakes on freedom of
expression and access to information, censorship or loss of data following the
closure of a service…  Fortunately, a band of irascible Gauls, meeting
around the Association Framasoft [^3] is bravely trying to “*de-googlize”* the
Internet [^4] and extend this initiative so that we can “retake control” [^5].

## The dangers

### Spying

These services track us everywhere, while claiming to give us a better “user
experience”.  But our behaviour is under constant surveillance.  This
information can be used to display targeted adverts, but the revelations of
the Snowden case have also shown that Internet giants have been forced to
communicate this data (sometimes extremely private: emails from Gmail, photos
shared on Facebook, Skype conversations, smartphone locations, etc.) to the
authorities.  Under the pretence of fighting terrorism, states are able to
gather much more intelligence than “Big Brother” could ever have dreamed of.

### Privacy

Our data is an extension of ourselves.  It tells third-parties where we are,
who we are with, our political and sexual orientations, sites we have visited,
our favourite recipes, our favourite topics of interest, and so on.

While a single data point is not always sensitive, the loss of large amounts
of aggregated data can be dangerous (for example if you browse topics about
cancer before subscribing to a life insurance). 

Your private life is an essential part of your individuality, and in a world
where everything has been digitized (e-books, TV, phones, music, social
networks, etc.), it would only take a malicious hacker with access to your
smartphone a few minutes to cause you serious harm (taking control of your
identity on Facebook, consulting your professional or medical information,
making purchases without your authorisation, etc.). 

### Centralization

The major actors of the Internet have become real giants: Google owns YouTube
and Waze, Facebook has acquired WhatsApp and Instagram, Microsoft distributes
Skype, etc.

This concentration of actors creates multiple issues: what if Facebook were
suddenly shut down?  And how could we browse the Web if Google went down? We
rely more and more on services provided by a small group of suppliers.  For
example, Apple (iPhone), Google (Android) and Microsoft (Windows Phone)
dominate almost the entire mobile OS industry.

Furthermore, the size of these actors impedes innovation: it’s hard to
launch a startup that can match up to Apple or Google (the first and
second worldwide market capitalisations, respectively).

Finally, The lack of diversity of the giants means they can track many people
who are unaware that there may be alternatives, and it can influence the kind
of data you receive (a Google search will produce different results for the
term “nuclear power” depending on whether Google considers you to be an
environmentalist or pro-nuclear power). 

### Termination

Web services used on your computer, smartphone, tablets (and other devices)
are usually hosted on the “cloud”: servers spread across the planet, that host
not only your data (emails, pictures, files, etc.), but also the application
code. 

For your data, this raises the issue of sustainability (what would become of
your files if Dropbox were to close tomorrow?) and of your ability to switch
easily between services (how would you recover your data from Facebook or
Picasa and import it, with all the adjoining comments, into another service?).

For applications, this means that you are completely at the mercy of your
service provider when it comes to proliferation of advertisements, changes
to the user interface, etc., and that you have hardly any control over the way
an application works.  It is a “black box” that can exhibit malicious
behaviour (sending spam SMS without your knowledge, executing malicious code,
and so on).

In short, these companies trap us in gilded cages: gilded yes, but cages
nonetheless!

## “De-googlize” the Internet

Framasoft, through the “de-googlize” the Internet initiative, wishes to
counter these threats to our digital lives by offering free, ethical,
decentralised, and solidarity-based services.  They are making a list of the
most-used proprietary software, linking them to the corresponding free
software they offer for those same services [^6].

In 2017, around forty online services were offered free to internauts with a
view to meeting a variety of needs: *cloud*-type personal file storage,
calendars, contacts, collaborative document editing, video conferencing,
cartography, mind mapping, meetings and surveys, distribution lists, social
networks, online books, search engines, educational games, project management…
the list is long, but “the way is free”.

### Freedom

The story of the Internet itself is one of free software, and this goes for
standards as well as protocols.  Its potential and popularity are a cause for
envy, and large companies would like nothing better than to control it by
imposing closed-source, locked-down, and non-interoperable systems.

For the Internet to stay true to its founding principles, those which have led
to its success, users must be able to choose free software.  That is to say,
software whose source code remains open and accessible and is covered by a
free software license.

### Ethics

Framasoft is committed to only using software with “free” source code,
promoting an internet that allows exchange and independence. 

We oppose the exploitation, surveillance, censorship and the appropriation of
data in favour of transparency (probity), clear presentation of a service’s
terms of use and a rejection of discrimination. 

Framasoft undertakes not to exploit its users’ data, and to promote a fair and
open Web.

### Solidarity

Through the services we deploy, we promote an economic model based on sharing
costs and resources, and providing widespread access. 

This model also has an educational aspect because we believe that by
documenting ways to setup services, many users will in turn be able to share
these resources. 

We think that, by not infantilizing users and by sharing responsibility for
the use of services, it will be possible to regulate abuse. 

Framasoft is thus committed to promoting respect and autonomy for its users
(as long as this is reciprocated).

### Decentralization

Internet intelligence must remain with each individual player on the network,
in a spirit of sharing among peers, to avoid creating Minitel 2.0 [^7] [^8].

To ensure equality for all, whether citizens or businesses, not only is it
essential to avoid monopolies, but large organizations must be prevented from
grabbing personal or public data. 

Using tutorials to explain how to increase the use of free solutions that will
allow a fairer Internet, we help to distribute codes and diversify usage. 

Framasoft is thus committed to facilitating self-hosting and interoperability,
so that its users don’t get “locked in”.
## The K.I.T.T.E.N.S. project[^9]

In the light of the success of their “de-googlize” the Internet campaign,
Framasoft has seen a vertiginous increase in the number of users of their
online services, with a corresponding increase in the work needed to maintain
and guarantee those services, without ceasing to propose new ones.  The
Association, lead by five permanent members, relies largely on donations and
does not want to grow beyond “human” size.

To extend the dynamic and encourage the decentralisation of services,
Framasoft therefore launched the KITTENS initiative, with the aim of bringing
together different structures and initiatives hosting services, data and
content in their own way, but respecting a common manifesto and charter [^10].
Both documents are collectively written and modified by the members of the
collective, to take into account the evolution of the different structures and
the technical, social and legal context of data hosting in France.

### General policy

The KITTENS collective employs a model of governance directly inspired by Free
Software.  Decisions concerning the evolution of the collective and the
charter are taken in a collegiate fashion.  Like source code, the collective
model can be duplicated and modified by whoever wants to adapt it, for
example, to specific regional contexts.

Each member is invited to participate in collective decision making by
consensus, as far as is possible.  In the case of conflicts of opinion,
decisions are made by a simple majority vote.

The domain chatons.org is maintained and hosted by Framasoft (as long as that
is possible and until the collective decides something else).  It is made up
of a website, with a list of members, and also a distribution list that
enables members to communicate and exchange.  They are invited to collaborate
in the creation of public content for the site, to inform the public of
information relating to KITTENS and its free hosting.

KITTENS has no administrative statutes as it principally consists of a public
list which determines the members and a set of documentation to facilitate the
exchange of knowledge, capitalisation on good practice, and information
sharing. 

Any organisation that respects the principles of the current manifesto and the
KITTENS charter can propose itself as a member.  In order to become a member,
the collective must receive contact information for the organisation and at
least one member of the organisation must be subscribed to the discussion
list.  Apart from the discussion and possibly some advice, there may also be a
vote by simple majority to decide on the the acceptance of a new organisation
into the collective. 

One or various members can reserve the right to request the expulsion of
another member, so long as the following conditions are met:

- the proposal must be supported by convincing arguments that are shared with
    all the members;
- it must be accepted by a collective vote, with or without counter arguments.

In awareness of the fact that it is not possible to guarantee respect for all
the points in the KITTENS charter without threatening the confidentiality of
the personal data held in the member's systems, peer control will *de facto*
be imperfect.  The collective therefore relies on trust and on the benevolence
of the agreements reached between members.

KITTENS should therefore meet among themselves, respecting each others’ points
of view, and find good practices and rules for inclusion, for questioning or
expelling a member, prioritising respect for fundamental freedoms and the
private lives of the users of collective services.

### Commitments

Each member, referred to below as a "KITTEN", commits herself to obey the
charter that defines the following principles:

 * Transparency, non-discrimination and protection of personal data.

 * Honesty is the watchword of these commitments, which seek to establish the
reliability of the proposed services and build user trust.  The General Use
Conditions should be perfectly clear, accessible and non-contradictory with
the KITTENS charter.

 * The host should implement a transparent user account management policy,
without discrimination, whether access is free or paid for.  It must respect
the jurisdiction of the country in question.

 * The host commits to allow all users to recover their personal data, encrypted
or not, except in the case of particular services based on the the momentary
transfer of encrypted personal data. 

#### Openness, economy, protection

The services proposed should meet some technical requirements.  Notably,
servers should be based on free software solutions.  Such software will make
the reproducibility of the service possible, without generating additional
developments in the structure of the server, or as a contribution to free
software.

The use of open formats is obligatory, at least for all data sent to users.
This is a clear policy in favour of interoperability.  When the use of open
formats is impossible, the data should be under a free license and be
available for as many operating systems as possible.  The sources should be
made accessible.

Members of KITTENS commit to respecting the free licenses for the software
that they use (which includes mentioning those licenses and referencing the
sources). 

In ethical terms, sponsoring is acceptable, as is patronage, donations, or
having an economic model that consists of demanding payment for some functions
or even for the entire service.  The economic model of each KITTEN should be
clearly expressed on a dedicated page that is easy for users to consult and
understand.  Evidently, the economic aspects of the activity of any KITTEN
should strictly conform to the legislation of the country in question.

On the other hand, no advertising coming from advertising agencies will be
accepted.  Likewise, there should be no exploitation of personal data, there
will be no monitoring of user activity except for legal and statistical ends,
user addresses may not be used for anything other than administrative or
technical ends.  Statistical tools should be free and meet the Collective's
conditions.

#### Solidarity and dissemination

KITTENS members owe each other assistance and mutual aid, through a discussion
list or any other means, including periodic meetings.  That is how KITTENS
members can progress their services.  One of the most effective means for
maintaining systematic mutual aid is by contributing to the development of
free software tools.

Nevertheless, members should not keep to themselves as that would only satisfy
a limited number of people and would create discrimination in access to
services.  On the contrary, all efforts at communication with the public are
encouraged as a way of disseminating free hosting solutions and creating links
around the principles defended by the collective.  The means should be shared,
through trainings, public information sessions, stalls during demonstrations,
speeches at conferences, the publication of leaflets, etc.

#### Neutrality

KITTENS services cannot be hosted by an actor who, by reputation, does not
promote the neutrality of the Net.  Data packages should be transmitted by
KITTENS services without discrimination, which means the content, source or
destination should not be examined.  No communications protocol can be given
priority in the way informaiton is distributed.  And no data can have its
content arbitrarily altered.

The neutrality of KITTENS is therefore a political neutrality, as the
convictions of members will be neither examined nor sanctioned, so long as
they keep within the framework of current applicable laws. 

#### AMIPO, an experience of a KITTENS construction in Orleans

AMPIRO, (“L’Association de Maintien de l’Informatique Paysanne Orléanaises,”
the Association for the Maintenance of Computing for Farmers in Orleans) is a
part of the French “AMAP” (Association of Organic Agriculturists who provide
their fruit and vegetables directly to subscribers), with the idea of finding
good bytes in a local association, rather than on the American “supermarket”.
A “farmer” is defined as anyone who works for self-sufficiency and contributes
to developing the environment and the countryside…

Signing up to a local KITTENS initiative starts with bringing together a group
of people motivated by the idea of practical reflections about the *why* of
the *how*.  From the first prototypes of services installed on recycled
servers behind a decidedly asymmetrical internet uplink (with more download
than sending capacity via ADSL [^11]), they aim to pass to the “production”
phase on servers hosted with ethical providers in synchrony with our base
values (Such as ARN [^12] in Alsace or Tetaneutral [^13] in Toulouse).

That requires setting up a legal entity (in this case, a collegiate
association [^14], without a president or head office); opening a bank
account; organising a launch event to raise funds; creating content to raise
awareness and setting up workshops for popular education; agreeing about the
technologies used and the services proposed; deciding whether the welcome page
of the website should be in http or https; creating the necessary
communication and documentation tools; organising the installation and
administration of the servers; making sure we are in accordance with the
charter, particularly putting in place the necessary safeguards; proposing
times and channels for communications in order to respond to user's questions…

The main aim of AMPIRO is to offer a *personal cloud* service (based on
NextCloud) that allows inventories of files, contacts and calendars, for free,
with the possibility of having more space by joining the association.  The
enthusiasm of the collective does not stop there, there may be a VPN (Virtual
Private Network [^15]), or work on end-to-end encryption, so that we cannot
read the data that are trusted to us, in order to be able to propose services
to local associations or to accompany cooperative projects in the IT usage.

With our calloused hands, as crude farmers in computing, we wish to plant as
many seeds as possible in the heads of our fellows so that little pixelated
*kittens* can run about on free and tree-lined roads. 

[^1]: In the first instance, in order to convince CERN that a system of global hypertext was interesting enough for the research centre, this document foreshadows the World Wide Web as we know it today: https://www.w3.org/History/1989/proposal-msw.html

[^2]: https://www.theguardian.com/technology/2017/mar/11/tim-berners-lee-web-inventor-save-internet

[^3]: https://framasoft.org/

[^4]: https://degooglisons-internet.org/

[^5]: https://framabook.org/numerique-reprendre-le-controle/

[^6]: https://degooglisons-internet.org/alternatives

[^7]: Benjamin Bayart: Internet libre, ou Minitel 2.0?    https://www.youtube.com/watch?v=AoRGoQ76PK8

[^8]:  Translator's note: Minitel was a centralised pre-Internet videotext terminal and service in France: https://en.wikipedia.org/wiki/Minitel

[^9]: Translator's note: The French initiative is called “C.H.A.T.O.N.S.” (<https://chatons.org/>).  Chatons means “kittens” in French, and stands for “Collectif des Hébergeurs Alternatifs, Transparents, Ouverts, Neutres et Solidaires” (the Collective of Alternative, Transparent, Neutral and Solidarity-based Hosters).   This is translated into English as “K.I.T.T.E.N.S.” (Keen Internet Talented Teams Engaged in Network Service).  For more information see: https://framagit.org/framasoft/CHATONS/blob/master/docs/Charter-en.md

[^10]: https://chatons.org/charte-et-manifeste

[^11]: https://fr.wikipedia.org/wiki/ADSL

[^12]: http://arn-fai.net/

[^13]: https://tetaneutral.net/

[^14]: http://www.passerelleco.info/article.php?id_article=103

[^15]: https://fr.wikipedia.org/wiki/R%C3%A9seau_priv%C3%A9_virtuel

