# From appropriate technologies to re-appropriated technologies [^0]

Increased investment in knowledge related to technology development means that
much of the technology we use today are commercial goods.  Acquisition and
transfer of technological knowledge ceases to be an informal process of the
commons.  Instead, it is subject to the laws and interests of the market, such
as patents and intellectual property registers.  It is therefore developed
mostly by large corporations and nation states.  The result is excessive
automation, which causes obligatory human displacement, wastes resources and
disempowers users through decreasing social knowledge about technologies.

The absence of scientific and technological capacities, the lack of economic
conditions that would encourage innovation, and inadequate introduction to
technologies generate economic changes in the realities and priorities of
countries.  The imbalance in the trade in knowledge creates a great difference
between countries and individuals and puts those who are net importers of
technology – or simply consumers – at a disadvantage in the relationships of
economic exchange.  The state of dependence and inequality in development is
observed when the principal source of technology in a country is located
abroad, and when there is no local capacity for generating and adapting its
own technology.  The import of technologies is not, in itself, necessarily a
disadvantage (all countries do it).  The bad thing is the absence of correct
policies of transferral of the associated knowledge and the dependencies that
this generates.

The introduction of an inadequate technology, one that is not understood, to a
community, or its adoption by an individual, creates a vicious circle of
technological dependence and an economic evolution incompatible with social
needs.  That dependence becomes a cause, symptom and consequence of the lack
of autonomy.  Thus, evolution and technical changes in the economies of the
countries of the misnamed “Global South” are substantially different from
those observed in the countries of the Global North or Western block
countries.

The technological imbalance that capitalism introduces may be key to the
creativity for meeting needs through appropriated technologies.  If we make
the situation reversible again, new and unstoppable processes of autonomy
emerge.  At the end of the day, what community does not need efficient
technology that is understandable and adapted to the specific environmental,
cultural and economic context?

## Interlinking concepts

Appropriate Technology [^1] means technology that is adequate, useable,
shared.  Appropriate technologies can be high or low tech, they are built and
distributed with free licences, GNU GPL, free and open source software and can
occur in various fields of action from agriculture, permaculture, gardening
and construction to communications, health and education.

The term originally emerged from the Anglo-Saxon environmentalist movement
during the 1973 energy crisis.  In his book, “Small is beautiful” [^2] the
British economist E.F. Schumacher promoted the value of technology as health,
beauty and permanence.  In this sense, appropriate technology is best suited
to the environmental, cultural and economic context; requiring few resources;
implying the least costs; with a low environmental impact; low levels of
maintenance; created using local skills, tools and materials; and that can be
locally repaired, modified and transformed.

The term appropriate, as a synonym for adequate, can generate confusion.  An
expensive technology could be the most adequate for a healthy community with
the capacity to pay for its maintenance, thus activating economic flow and
concentrating it on reinforcing the direction of those with most power.

In terms of intermediate technologies, these can also be appropriate.  They
tend to be much less costly than the prevailing technology, and be built using
materials and knowledge available locally, easily bought and used by people
with little access to resources.  They can increases production whilst
minimizing social dislocation.

“Slow Design” [^25] is an holistic design focus that takes into account the
broadest range of material and social factors, including short and long term
impacts.  In “Slow Design, a paradigm for sustainable living”, Alistair
Fuad-Lucas develops sustainable design, balancing sociocultural, environmental
and invididual needs.  The concept is applied to experiences, processes,
services and organisations.  It is a road to the dematerialisation necessary
for sustainability in the long term.  It seeks human well-being and positive
synergies between the elements of a system, celebrating diversity and
regionalism.

Re-appropriated technologies mean rethinking technologies we need from a
political position.  It means placing technology at the centre of life, within
a transversal axis where other disciplines such as ethics, social problems or
the environment can also be found.  It seeks to integrate them all into a
whole, with a view to preserving and defending life against power, so that it
is not oppressed.  When we place technology at the centre we don't necessarily
build a technological world like the current one, filled with dependencies and
frustrations and ties that upset the balance between the powerful and the
oppressed.

If our desire is to bring about social change towards a more sustainable,
collective and communal society, we must change the means, the resources and
the relationships that currently sustain society based on economic interests.
We must return to ourselves, individuals and communities, women and peoples,
the part of our technological empowerment that has been expropriated from us.
We must generate a technology, a science, and the their dissemination, that is
focused on life – just as it was before the Industrial Revolution.  It will be
necessary to change the structures and above all those that sustain knowledge,
because if the whole system and the processes change, but the the structures
and the relationships that form between us do not, then nothing has changed.

Re-appropriated technology has a political determination to fragment the
capitalist system, favouring the creation of small, decentralised communities
of equality and self-organisation.  Re-appropriated technology calls for a
less alienated society, more integrated with natural processes.
Re-appropriated technologies are implanted by the individuals and communities
themselves, not by governments.  Such policies cannot be designed without
going to the territory, and government work only happens in the management
decisions taken in offices.  We need re-appropriated technology that
incorporates our ancestral traditions in the context of industrialisation, and
brings back these technologies and techniques to our daily lives.  Ancestral
traditions have an already inherently environmental, sustainable and holistic
foundation.  We need technologies that create well-being, beauty and
community.

## Re-appropriated technologies from personal experience

Over the past 10 years I have tried to carry the theory into practice, I have
adapted and changed my ways, I have created protocols and free licenses that
defend our re-appropriated technologies.  I have tried to generate collective
workshops where people exchange experiences and skills and which could extend
to productive activity that will cover basic needs and enrich the communities.

I have discovered an existing market niche for re-appropriated technologies:
one way to describe it would be “in order to be productive and sustainable, a
producer of organic walnuts or almonds has no intermediate solution between a
nut-cracker and a super machine costing thousands of Euros.  Re-appropriated
technologies would occupy that space, adapting to the user and to their
environment”.

Society as a whole, and the majority of social movements, have not defended
technology, science or technological sovereignty as a social practice, for the
individual or the collective.  The debate is marginalised, and little by
little, new technologies are introduced into our daily lives, making us more
dependent and having little to do with the four freedoms.  Thankfully there is
always a minority group that reverts or questions this.

In the majority of technological spaces, the majority of participants belong
to the patriarchal male gender.  This situation has not changed yet and often
that machismo gets more ferocious, because it is not only present in the
content, but also in the ways of doing things, in the treatment received, in
the general atmosphere, in the working environment.  These are marked by
competitiveness and egos that are touched only at great risk of being
victimized.  These macho attitudes are all the more significant because we
come from a scene with an understanding of questions of gender, yet people
simply don't want to change the existing privileges, or they are afraid of
reconsidering them because sometimes it is easier to defend oneself than to do
the internal work required.  I will give you a real example of a case that
happened to me with two crane drivers.

**Situation A:** We had finished working with an oxygen trailer [^35] and they
had to take it away with a crane.  A man arrives.  He puts some straps around
the tank which, when they are tightened, mark a small bulge in the trailer,
which is made of multiwall polycarbonate.  I said to him:

> “Excuse me, it would be better to put a cloth under the straps so that they
> don't mark the trailer.  That way it will arrive to my client in a perfect
> condition.”

> “Don't worry, it is fine like that.  It's fine” He says, without listening
> to me.

> I wait 30 seconds to answer him.

> “Hey, put a cloth, it's no trouble.”

> “You'll see how much they mark it in the ferry.  This is nothing” He is
> still not listening to me.

> A minute of deep breathing, and I think, I am the client, if I tell him to
> put a cloth under it, he should just put a cloth under it.  Why so stubborn?

> “I'm sorry, but it is better if we put a cloth”.  Finally, with gritted
> teeth, he does it.

**Situation B:** My car broke down in the middle of the mountain when it was
terribly cold, and I was waiting for the tow truck to arrive.  The truck
driver arrived and she told me that my breakdown could be fixed if we took out
a tube.  She could not get it off because her hands were freezing, and my hand
unconsciously moved to help her.  OK, perfect.  She was not shocked, she did
not say I was getting in the way, she just said thank you and we tried to
remove it together.

The intransigent attitude in situation A does not happen with all men, nor the
contrary with all women.  Rootless, competitive, intransigent, oppressive,
unequal attitudes belong to patriarchy and we can all be victims of them
whatever our gender.  Technology and science, as tools of power, advance
according to the directives of patriarchy and capitalist society.

Thus re-appropriated technologies should be something more than the
technological objects and the sciences in themselves, they should also be the
set of relationships that emerge around those objects.  Could re-appropriated
technologies be manufactured in a workshop with totally patriarchal ways and
attitudes?  I think not.  It makes no sense.

It is necessary to put technology at the centre of life, speak of cranks and
pistons, as we would speak of kitchen recipes.  That is what Jineology does
[^33], it does not separate the object from the subject, it mixes them within
a healthy relationship, not as something external, but as something that is
mutable and can always be improved upon.

Another nuance of re-appropriated technologies lies in how they are applied.
If we take similes from everyday life, we can simply make our bed, or we can
shake the blankets out of the window, leave them to air in the sun, brush the
mattress to remove creases.  Behind all these steps are techniques to improve
our lives.  Another example would be in the application of moisturising cream.
It is one thing to just wipe over it with your hand, and a very different
thing to carefully apply it with small gestures, the effects are far greater.

It is the same with everything.  Everything has techniques and science behind
it.  Learning these small habits is not so hard.  In order to incorporate
sciences that improve our lives, and make them habits, it is necessary not
just to do, but also to understand why we are doing it that way...

## Naming some re-appropriated technologies

In the field of **construction** there are a wide diversity of techniques: Adobe,
Super Adobe, Clinker bricks and Corncob insulation among others.  All are made
with local materials that are relatively cheap.  Architecture for Humanity
[^10] follows consistent principles with appropriate technologies, aimed at
people affected by natural disasters.

In the field of **energy**, Amory Lovins' term “soft energy” [^12] describes
renewable and appropriate energies.  These tend to be introduced into isolated
communities and places with low energy requirements.  There are off-grid
designs [^11] that are not connected to mains electricity.  The high costs of
the initial investments and training for maintenance need to be taken into
account.  They use solar panels, which are initially expensive but simple,
wind generators or microturbines in waterfalls, and this energy is stored in
batteries.  Biobutanol, biodiesel and vegetable oil can be appropriate in
areas where vegetable oil is abundant and cheaper than fossil fuels.  Biogas
is another potential source of energy, particularly where there is an abundant
supply of organic waste.

In **lighting**, the Light Up World Foundation [^13] uses LED and renewable
energy sources, such as solar cells, to provide light to people with little
resources in remote areas, to replace dangerous kerosene lamps.  The Safety
Lamp [^14] is a kerosene lamp designed in Sri Lanka, that has a metal top and
two flat sides to stop it rolling if it is knocked over.

In **food preparation**, intermediate technologies are used to reduce the
labour required by traditional methods, for example, the Peanut Peeler in
Malaysia.  In kitchens, fair kitchens, smoke reducers and efficient stoves
save time, reduce deforestation and are beneficial for health.  Briquettes
[^15], developed by the Legacy foundation [^16], transform organic waste into
fuel.  Solar Ovens are appropriate in some areas, depending on the climate and
on local cuisine.

In **refrigeration**, the pot-in-pot refrigerator [^17] is an African
invention that enables them to keep things cool without electricity for far
longer.  This is of great benefit to the families that use it.  For example,
the girls who sell fresh shellfish in the market can leave the shellfish in
the device while they go to school and go to the market later.

In **water**, the Hippo Water Roller [^18], enables more water to be carried
with less effort.  The Rain Water Harvester requires an appropriate storage
method, particularly in dry areas, and the Cloud Collector is excellent for
areas where rain is scarce.  In Water Treatment, high standards must be
applied when water must be purified before use.  Ground water could be could
be clean enough, depending on the depth and the distance from sources of
contamination such as latrines; rain water can be clean if the area where it
falls is free of waste.  Nevertheless, it is advisable to treat it to remove
possible contamination.  The principal processes are: filtering, biofilm,
sedimentation, heat, UV light, and chemical disinfection using chlorine.

Soft-sand filters provide high quality treated water through a simple
operation, used both in healthy nations and poor communities.  Crushed
*Moringa oleifera* or *Strychnos potatorum* seeds can be used as coagulants,
impurities are easily removed by sedimentation and filtration.  Ceramic
filters, made of clay mixed with an organic material such as coffee, are found
in many homes in South America.  The LifeStraw [^19] is a small device that
allows the user to drink directly from dirty water.  Cloth filters or solar
disinfection are useful at a small scale that requires few jars or bottles.

In **accesibility**, the Whirlwind wheelchair [^23] provides desirable mobility
for people who cannot buy the chairs used in developed countries.

In **sanitation**, BiPu [^20] is a portable latrine system appropriate for
disasters.  The Orange Pilot project [^21] was a solution for the sanitation
crisis of urban neighbourhoods, and the low-cost latrines developed in
villages in Bangladesh responded to health problems caused by open sewers.
Reed beds [^22] purify grey water.  Ecological sanitation treats human waste
in order to protect both human health and the environment, with water being
used for hand (and anus) washing, while nutrients are recycled to help reduce
the need for artificial fertilizers.

In **healthcare**, the phase-change incubator created in the late 1990s is a
low cost way to create microbiological samples.  A number of appropriated
technologies exist to benefit public health, particularly the use of clean
water in sanitation.

Finally, in the area of **Information and Communications Technologies**, we
have the 2B1 [^5] and the Simputer [^6] computers aimed at developing
countries, where the principal advantage is low costs, resistance to dust,
fidelity and local language support.  ILDIS OnDisc [^7] uses CDs and DVDs in
areas without a reliable connection to the Internet nor sufficient money.
Wind-up [^8] by Jhai Foundation, makes radio, computer and communications
systems autonomous.  Mobile telephones can also be re-appropriated
technologies in places where commercial providers cannot or does not want to
ensure widespread coverage.  Loband [^9], developed by Aidworld, strips all
bandwidth intensive content from Internet traffic and converts web pages to
simple text, increasing transmission speed, making it appropriate for slow
connections.

## Conclusions

No technology is adequate in absolute terms.  According to the UNIDO [^26] it
is a case of “the technology that best contributes to the economic, social and
environmental objectives, taking into account the development challenges,
resources and conditions for application in each territory”.

Adequate technology makes optimum use of available resources in a territory to
maximise the well being of the population.  Economic sectors with different
characteristics make different technologies.  Ideally there should be patterns
of balanced development, where extracted resources can gradually replenish
themselves in equilibrium.  Products should be developed to account for income
levels and for the different lifestyles that exist.  Needs should be met, not
generated.  Small scale is preferable to large.

Adequate management is associated with the generation, transferral,
adaptation, assimilation and internal dissemination of the necessary
technologies to meet social and economic needs, without ignoring the
ecological balance.  To reach this, there must be consensus, and an
organisation capable of integrating a continuous process of technological
management, guided by a strategy that harmonises the functioning of the
techno-scientific system with the transformation and development of the
productive system.  This organisation must constantly question and it must be
particularly involved in dissemination and education.  It is therefore
important to be based on local needs, decentralised structures, small nuclei,
and communities with stable networks of trust and reciprocity.  If there is a
major management structure in a country, it should incorporate the needs of
these nuclei, from the bottom up.  Poor individuals and countries should
remember that they have the possibility to have their own voice, and take
responsibility for ensuring that their decision making power in terms of their
own economic and social evolution is respected in this interdependent world.

[^0] There is a longer version of this text available in Spanish
here:
http://elleflane.colectivizaciones.org/wp-content/uploads/2017/02/Tecnologias_reapropiadas2017.pdf

[^1] Appropriate technology:
https://en.wikipedia.org/wiki/Appropriate_technology

[^2] E.F. Schumacher: *Small is beautiful*.

[^5] 2B1: http://en.wikipedia.org/wiki/2B1_conference

[^6] Simputer: http://en.wikipedia.org/wiki/Simputer

[^7] ILDIS OnDis:
http://books.google.es/books/about/The_Transfer_of_Technology_to_Developing.html

[^8] Wind-up radio: http://en.wikipedia.org/wiki/Human_power

[^9] Loband: http://www.loband.org/loband/

[^10] Archuitecture for humanity: http://architectureforhumanity.org/

[^11] Off-grid design:
http://www.off-grid.net/energy-design-service-questionnaire-spanish/ 

[^12] Soft Energy: http://en.wikipedia.org/wiki/Soft_energy_technology

[^13] Light Up World Foundation: http://lutw.org/

[^14] Safety Lamp: http://tecno.sostenibilidad.org

[^15] Briquette http://en.wikipedia.org/wiki/Biomass_briquettes**

[^16] Legacy Foundation: http://www.legacyfound.org/

[^17] Pot-in-pot refrigerator:
http://www.mienergiagratis.com/energias/mucho-mas/mas-proyectos/item/66-p000028.html**

[^18] Hippo Water Roller: http://www.hipporoller.org/

[^19] LifeStraw: http://eartheasy.com/lifestraw

[^20] BiPu: http://en.wikipedia.org/wiki/BiPu

[^21] Orange Pilot.

[^22] Reed beds: http://www.wte-ltd.co.uk/reed_bed_sewage_treatment.html**

[^23] Whirlwind: http://www.whirlwindwheelchair.org/

[^24] Cloth Filter: http://en.wikipedia.org/wiki/Cloth_filter

[^25] Slow design: http://en.wikipedia.org/wiki/Slow_design

[^26] UNIDO, United Nations Industrial Development Organisation:
http://unido.org/

[^27] *A Guide for the Perplexed*:
http://www.appropedia.org/A_Guide_for_the_Perplexed

[^28] Alternative technology: http://www.ata.org.au/

[^29] Eco-village: http://www.ic.org/pnp/cdir/2000/08ecovillage.php**

[^30] StewartFrances: *Technology and underdevelopement*, 1983.

[^31] Isaías Flit: *Tecnologías apropiadas o manejo apropiado de las
tecnologías*.

[^32] Fuad-Luke Alistair: *Slow Design' - un paradigma para vivir de manera
sostenible?*.

[^33]
https://comitesolidaridadrojava.wordpress.com/2015/02/19/por-que-jineology-reconstruir-las-ciencias-hacia-una-vida-comunitaria-y-libre/

[^34] Heberto Tapias García: *Tecnología adecuada*.

