# Simultaneous Interpreting Using Radio Frequencies

*[COATI](mailto:coati@pimienta.org) – Colectivo para la Autogestión de las Tecnologías de la Interpretación*

## Introduction

> *“International solidarity and global protest is nothing new. From the European-wide revolutions of 1848, through the upheavals of 1917-18 following the Russian Revolution, to the lightning flashes of resistance nearly everywhere in 1968, struggle has always been able to communicate and mutually inspire globally. But what is perhaps unique to our times is the speed and ease with which we can communicate between struggles and the fact that globalisation has meant that many people living in very different cultures across the world now share a common enemy.”* – Do or Die, Issue 8, 1999.

> *“Our resistance is as transnational as capital”* – Slogan of the global day of action against capitalism, June 18th 1999.

As the economy has become increasingly transnational, so too has resistance to its devastating social and ecological consequences. International resistance means coming together from different struggles and cultures to meet, share ideas and experiences, and coordinate actions. Crossing borders and cultures in this way means communicating across language barriers, and language is about power.

Many international gatherings take place in the more ‘international’ languages, such as English, Spanish, Russian or French. Many people speak these languages, but that is because they have long histories of imperialism: they were forcibly, and in many cases brutally, imposed on people from many different cultures, devouring local languages and eradicating cultural diversity. They can help us communicate, but they are often not people's first language, and people participating in a foreign language may be unsure if they have understood everything correctly, or they may lack confidence about expressing themselves well. Events are often dominated by people who feel comfortable with the majority language; thus native speakers of colonial languages (particularly English) have dominated history and they continue to dominate our meetings.

If we are committed to diversity, grassroots participation or consensus decision-making, we must raise awareness of these power dynamics and processes of inclusion and exclusion. Increasing the equality of our communication and creating space for speakers of other languages is an important political struggle, and one valuable tool for dealing with this is providing interpreting between languages so that everyone can communicate in a language they are comfortable with.

Interpreting between two languages is an art as ancient as languages themselves and requires no technology. However, for interpreting to be practical in larger meetings in several languages it must be simultaneous; and multi-language, simultaneous interpreting cannot happen without technology.

## A history of alternative interpreting technologies

The first attempt to use technology to facilitate this type of interpreting seems to have been at the Nuremberg trials after the Second World War, using a system based on the telephone [^telephone]. Since then, the technology, usually based on infrared transmission, has developed alongside international organisations such as the UN and the EU. It is now very advanced but extremely expensive and out of reach for most activist spaces and social movements. Even if an event can afford to hire some equipment the costs soon become astronomical if you want to work at any kind of scale.

The European and World Social Forums (ESF and WSF) that took place between 2001 and 2010 were international events on a massive scale, with up to 100,000 participants and hundreds of parallel meetings taking place every day. Initially, interpretation was very limited, due to costs, but some people quickly realised the importance of languages to the political process, and Babels, a network of volunteer interpreters, was born.

Interpreting and interpreting technology became part of the political process. Interpreting is easiest in large plenary sessions where a few people speak and most just listen. Participatory organising requires working in small groups, where more people have the opportunity to contribute, but this multiplies the interpreting resources required, so decisions about interpreting affect the working dynamics of an event. The prohibitive cost of commercial technology and interpreters limits available resources, and there is no such thing as a purely technical choice. Even if there is money to pay for the service, it is a one-off thing: you give it to a commercial company and it is gone. The alternative is to "Do it Yourself", invest in people and equipment and thus increase the capacities and autonomy of the movements.

At the 2003 ESF in Paris, over 1000 volunteers took part in the interpretation, and every plenary and workshop took place in several languages. However, the technology used was commercial, and the costs were astronomical. Full-scale, commercial interpreting technology has never been used again in an event of that size. This inspired the first experiments in alternative interpreting technology. Initially, these were based on computers, but digitalisation introduced long delays that confused interpreters and public alike. At the 2004 WSF in Mumbai, India, computers were abandoned for more low-tech, analogue solutions, transmitting through cables and via FM radio. In Greece, a collective known as ALIS (ALternative Interpreting Systems) was formed to provide interpreting technology for the 2006 Athens ESF. Using the blueprints and building on the experiences of earlier groups using analogue interpreter consoles and FM radio transmission, they spent months building enough equipment to cover the entire event.

Athens was the first (and for Social Forums sadly the only) time that a large political event fully recognised alternative interpreting technology as a political question in itself and gave it the space and resources necessary to carry out its mission. The result was an unprecedented success. Infrared receivers are extremely expensive devices, jealously guarded by their commercial owners who require participants to deposit a passport or credit card in exchange for their use; but in Athens interpreting was made available to anyone with an FM receiver, and versions of that system are still being used by social movements today, allowing people access to interpreting through any household radio or smartphone.

Nevertheless, despite the success of Athens, the experience of working with the Social Forums was generally that the best efforts of interpreters and technicians were rendered completely ineffective by inadequate political and technical support at the events. Furthermore, there was no support at all between events, when equipment had to be bought or built, stored, transported, tested and repaired. Unlike commercial equipment which you rent for the duration of an event, self-managed equipment remains with you between meetings, and in greater amounts than any particular event may need. People have to be trained in how it works, logistical issues need to be solved and there are administrative loads to bear, all of which requires resources and dedication. The Social Forum process refused to learn that lesson, but other movements have taken it on board.

## COATI: The Collective for Autonomy in Interpreting Technology

COATI was formed in Barcelona in 2009, bringing together people who had participated in anti-capitalist and anti-globalisation movements. We had supported the peasant farmers of Via Campesina in the creation of the movement for Food Sovereignty, and had volunteered as interpreters (sometimes in very precarious conditions) and seen the value of good alternative technology; we had learnt to organise horizontally and by consensus in the Do-It-Yourself culture of anarchist and anti-capitalist social centres all over Europe; we had built an understanding of technology in the squatted hacklabs and free software communities; we learnt about sound systems running hardcore punk festivals, street parties and independent, community-based radio stations; and it was those experiences, and the values of those communities, that inspired the project.

We invited someone from the original ALIS collective to come to Barcelona and train us in how their equipment worked, and we began to track down as much of the old alternative technology as we could find (most of it was piled up in warehouses, or in forgotten boxes in campaign offices, gathering dust). Our commitment was to increasing linguistic diversity and our plan was to acquire and manage the equipment, so that each event didn't have to solve its technology problems from scratch. However, we quickly learnt that increasing access to interpreting technology was going to require more than just administering the equipment and reducing the costs.

## Making alternative technology work for people

The first challenge was to overcome resistance to using alternative technologies, often born of bad experiences people had had with the equipment in the past. Designed within the social movements, the system did not match the quality of commercial equipment. It was built with the aim of drastically reducing costs, using cheap material not specifically designed for audio, and interpreters and public alike could be plagued with an electronic buzzing noise that was exhausting to listen to for any length of time.

An important part of the solution was simply treating the technology as an important issue. We trained ourselves, and wherever our equipment went there was always a dedicated person responsible for operating it (many of the problems of the past were caused by alternative technology being treated as an afterthought, and no one having the time to ensure it was working well). We learnt as we went along and devoted a lot of time to identifying the causes of problems and modifying the equipment, adding small circuits to filter and boost signals, and improve the quality of the sound.

This was made considerably harder because the material built by the Greek collective came with no schematics. This meant hours of reverse engineering were required before we could make modifications. Now, the equipment is almost 10 years old and we are beginning to face the challenge of designing and building new, open-source consoles from scratch. We are very aware of the value of open-source design, and all of the electronic work we have done is fully documented and available online [^online].

## Making people work with alternative technology

Overcoming technological problems was not the only challenge we faced. Some of the most difficult issues stemmed from the political and organising cultures of the movements themselves. Many groups are based on relatively informal organising and people can be resistant to the discipline simultaneous interpreting requires: people must speak slowly and clearly; use microphones so that the signal reaches the interpreters; and people cannot interrupt each other. Larger networks and NGOs may have more experience of working with interpreters, but they tend to treat it as a mere technical service that should be invisible and not as an important part of the political process. They get frustrated with the demands of solidarity interpreting and alternative technologies for participation and political involvement. However smoothly the technology is working, just having interpreting does not automatically eradicate the power dynamics created by language, and it must be everybody's responsibility to create space for more minority languages.

Another important part of the work done by COATI has therefore been working to promote the political culture that alternative interpreting technology needs to really work.

## Volunteer interpreting

Alternative technology can be used by commercial interpreters, and volunteer interpreters can work in commercial booths. However, in practice the two processes have developed very closely, side by side, and a key element of organising an event is often finding volunteers with the necessary skills to meet the language needs. You can deal with this by finding professional interpreters who are willing to work for free, either out of solidarity, or simply because they need work experience, or because travel and expenses will be covered to exotic places. However, this relationship risks becoming one of cheap service provision, with volunteers having little interest in the political issues being discussed; and the resulting expenses can be high even if the work is done for free.

A large part of our work is therefore helping movements to build the capacity for simultaneous interpreting within their own grassroots. The larger an event is, the more complex this process becomes and a whole article could be written just on the political and technical questions involved. Suffice to say it is a very important issue. We have developed a two-day training for activists with language skills, and we always try to incorporate skill sharing in the interpreting teams we coordinate, putting experienced interpreters together with new activist volunteers in our booths.

## Speaking for interpreters

Another important part of changing the political culture has been to raise the profile of language diversity among participants in international events. Wherever we work we try to give a political and practical introduction to the equipment, and provide written guidelines on how to speak in multi-lingual meetings [^multi-lingual]. We encourage people to actively think about the language they use, for example, asking them not to speak the majority language in a meeting even if they can, because it marginalises those who have to rely on the interpreting, leaving them feeling embarrassed and uncultured and less inclined to take part. We have experimented with subverting the invisible interpreting model, placing the booths centre-stage and having speakers speak from the floor, thus making everyone aware of the processes involved.

## Designing flexible solutions to meet political needs

Interpreting inevitably does impose limitations on what a meeting or gathering can do, and simultaneous interpreting is best suited to quite hierarchical forms of organising such as the traditional conference model. However, we are committed to non-hierarchical organising, and we make it a priority to understand a group's methodologies, needs and resources and match them to the technical and technological possibilities.

There are two main parts to this process. One is to work closely with event organisers to understand their political aims and help them to understand interpreting and interpreting technology and how they interact with different kinds of facilitation techniques and meeting dynamics. The other is to take a creative approach to the equipment, building little hacks using mixers and splitters, and wiring (or sometimes gaffer-taping) devices together in unconventional ways to make them do what we need.

We have built up a wealth of experience of pushing the boundaries of what can be done to break the mould of the typical meeting format, even in quite extreme circumstances. At the Second Nyeleni Europe gathering in Cluj-Napoca, Romania in 2016 we organised interpreters and equipment to work with experimental participatory methodologies with over 400 participants in more than nine languages, and we are now working on a technical and political guide to facilitation with multiple languages.

## The biggest challenge: Decentralisation

Over the past seven years we have worked with many groups and movements to help solve the language requirements of their international events. Very often this means us providing all the necessary technology and technicians, and coordinating the volunteer interpreters for the event. However, we also collaborate in mixed solutions, and help organizations to build or acquire their own equipment and build the capacity to meet their interpreting needs. We believe that real technological sovereignty means that groups don't have to rely on 'experts', but become empowered to meet their own technological needs. One of our biggest projects has therefore been the development of simple, easy to use, build-your-own open-source hardware.

## The Spider: An open-source hardware project

The simplest form of interpreting technology is probably the “Spider”: a small box you plug a microphone into, with sockets for headphones to take the interpreting to the public via cables, making it look like a big, lanky spider!

Compared to FM radio or other wireless transmissions, Spiders are cheap and very easy to operate. Spiders are a small-scale device, only really suitable for smaller meetings (although in extreme situations we have used them at events with hundreds of participants!) The real scalability of the project lies in the fact that any organisation can have a few, making them completely autonomous for many of their interpreting needs.

Years of experience went into developing and producing our own open-source version of the Spider, with many improvements such as modular extensions you can use to add listeners in groups of up to twelve.

We build our Spiders by hand for our own use and for sale; and also sell make-your-own kits at cost price. All the schematics, parts references and complete building instructions are published online [^online] under the GNU General Public License.

## Training new tech collectives

Since the Spider project went online we have run a number of electronics workshops, training people to build their own spiders, and we know of at least one group, in Ukraine that has built Spiders without any contact with us. We also work with technicians from other groups, inviting them to join us at large events and see how the technology works in the field; we have taken part in a number of skill-sharing weekends, helping new groups to get started; and we have participated in the creation of new collectives using Spiders and inventing their own interpreting solutions in Romania [^Romania] and Poland [^Poland] as well as an international collective, Bla [^Bla], that has Spiders and small radio kits that travel to different events around Europe.

## Conclusions

Sovereignty in interpreting technology has come to mean many things to us. In the first instance, to extend access to interpreting technologies to resistance movements it was necessary to reduce the costs, and develop high-quality alternative solutions that really work and are sustainable in the long-term. However, that was not the only challenge. A lot of political work still needs to be done to overcome people's resistance to using interpreting technology to open our meetings and gatherings up for speakers of other languages to participate on an equal footing. There is a need to share skills and knowledge about the technical aspects of interpreting and how those can interact with different kinds of facilitation dynamics; and open-source research and development that aims to maximise technological sovereignty must be accompanied by capacity building and political mobilisation, to increase people's awareness of why and how they should use the technology, and empower them to really control and create their own solutions.

For more information about COATI and the work we do please see:

<https://coati.pimienta.org>

Contact: <mailto:coati@pimienta.org>
