# Keeping technological sovereignty: The case of Internet Relay Chat

*Maxigas*

New technologies sometimes manifest a critique of the existing conditions, but their empowering affordances are often lost as their features are progressively integrated to the requirements of capitalism during their subsequent development. The history of chat devices is a textbook example of critique and recuperation in technological cycles. However, the social history and contemporary use of IRC (Internet Relay Chat) proves that such historical logic can be – and *is* – resisted in some exceptional cases. This case study does *not* necessarily recommend IRC as a medium of communication for activists, but rather seeks to put forward some theses on the history of technology that could be found useful in certain situations.

*The systematic study of such cases may contribute to the refinement of a taste for critical technology adoption practices in communities who wish to keep control over the technologies that mediate their social relations.* Therefore, an appreciation of critique and recuperation in technological cycles may help to further technological sovereignty (Haché 2014) over longer time frames, where local efforts could potentially become part of capitalist regimes of oppression and exploitation over time. A corollary observation is that technical features may result in crucially different technological affordances depending on their context of use: this shows that pure techniques should never be promoted or rejected in themselves.

## Internet Relay Chat

Internet Relay Chat is a very basic but very flexible protocol for real time written conversations. It has been first implemented in 1988, one year before the World Wide Web. IRC reached the height of its popularity as a general purpose social media during the first Gulf War and the siege of Sarajevo (1992-1996). At this time it performed various functions that were later fulfilled by specialised programs and platforms, such as dating, following friends or file sharing. As the population of the Internet grew and market consolidation set it on the turn of the millennium, IRC faded from the public view.

However, it is known from seminal studies of contemporary peer production communities that free software developers (Coleman 2012), hackerspace members (Maxigas 2015), Wikipedia editors (Broughton 2008) and Anonymous hacktivists (Dagdelen 2012) use primarily IRC for everyday backstage communication. While the first group has always been on IRC, the latter three adopted it after the apparent demise of the medium. “Why these contemporary user groups – widely considered as disruptive innovators and early adopters – stick to a museological chat technology despite its obvious limitations within the current technological landscape?” Currently popular social networking platforms, such as Facebook and Twitter, offer similar features and appear to be a more obvious choice. *I* propose that while IRC use can seem retrograde, it is actually a critical technology adoption practice that empirically evades, and analytically highlights the pitfalls of mainstream social media monopolies.

## Recuperation

*Critique and recuperation in technological cycles* is a process of integrating societal demands into the capitalist system. New technologies sometimes embody a demand for a better society and a critique of the existing conditions. While such demands are typically addressed by subsequent versions of the same technology, the same technology is also made to conform to the two main requirements of the capitalist system. These latter two are *the preservation of social peace (i.e. repression), and the intensification of exploitation (i.e. capital accumulation)*. It happens that the implementation of these two requirements neutralises the societal gains from the demand originally associated with the technology.

One aspect or form of recuperation is *commodification*. Commodification is when something at some point becomes a commodity to be brought and sold on the market, e.g. a commodity. Commodification targets *authentic* things, which are often already perceived to be valuable – for instance as a moral good – but not yet recognised as an object of monetary exchange. The loss of authenticity through commodification produces *anxiety* in consumers, which can be diagnosed as the affective trace of capital’s violence.

To summarise, *critique* addresses a social problem as a demand. *Recuperation* is the implementation of the demand, but in the same movement also the transformation of the technological context in a way that neutralises the critique. The requirements that the implementation of the demand has to paradoxically fulfil are (a.) keeping *social peace* (repression) constant while (b.) increasing *exploitation* (capital accumulation). *Commodification* is an aspect or mode of recuperation that often happens in technological cycles. Commodification targets *authentic* goods which are outside of the market, and integrates them into the circulation of commodities. *Anxiety* is the byproduct of commodification as the affective trace of capital’s violence.

## Chat history and other examples of recuperation

Recuperation as a historical logic can be seen at work in a wide range of technologies, from the history of chat to the development of personal computing. I concentrate on the history of chat devices because this is the context of the IRC story. While the history of chat devices is a textbook example of critique and recuperation in technological cycles, the story of IRC is a counter-example that shows the possibility of resisting the historical logic of capitalism.

Chat devices answered a basic human need to discuss arbitrary topics informally in a real time environment. After a long and parallel history of chat devices, in the 1990s they consolidated into IRC (more or less as a corollary to the consolidation of Layer 2 networks into the Internet). The next generation of chat devices were *Instant Messengers* (Maxigas 2014). On the backend (Stalder 2013), IMs used proprietary protocols and centralised infrastructures, instead of the community defined protocols of IRC and its federated model. On the frontend (Stalder 2013), IMs were organised around private conversations, in stark contrast with IRC’s concept of topical channels (itself taken from Citizens’ Band – CB – radio). Later, as the World Wide Web took off, chat features were integrated into Web 2.0 *social media platforms*.

Eventually, *surveillance* came to be the key means for both maintaining social peace and deepening exploitation on social media platforms.[^1] Everyday, informal, even intimate gestures are captured and stored, sorted and mined for the purposes of both targeted advertising and targeted repression. Such revenue is indispensable to the capital accumulation mechanisms of a growing section of capital, while the intelligence gained by authorities who share access to the information flows is essential to the maintenance of social order in both dictatorships *and* democracies. All this hinges on successful *platformisation*: the ability of a vendor to install themselves as an obligatory passage point for generally mundane and often minuscule social interactions (Gillespie 2010).

The anxiety experienced by users stems from the fact that a supposedly informal space of social interaction is mediated by capital and overseen by the state, through mechanisms that look obscure, arbitrary and partial from below. One can remember that the two defining characteristics of a healthy *civil society* that can support technological sovereignty are its independence from capital and separation from the state (Haché 2014). It is *privacy* in a structural and collective sense that can be reclaimed through technological sovereignty initiatives, but only through the continuous struggle of users for taking the technological mediation of their social life into their own hands.

It is important to realise that neither chat (Latzko-Toth 2010) nor personal computing (Levy 1984) were “inventions” in the sense that a good idea was implemented and socialised through commodity circulation. Both found a foothold in the market only after a relatively long period where fringe elements fought for them, often breaking existing laws, regulations and social norms. Society then slowly tamed these technologies – and now they are used to pacify society itself.

## Backlogs

### As a Human-Computer Interaction limitation

IRC is different from many other chat devices in that users can only follow conversations as long as they are logged in. If a particular user is not online, there is no way to contact her. Conversely, when a user logs back to a channel, she has no idea what she missed while she was offline. Due to the flexibility of the medium, there are many workarounds for the lack of backlogs, but the fundamental fact remains that solving this problem is out of scope of the IRC protocol. Network operators could solve the problem if they wanted, but in practice users are – literally – left to their own devices.

### As a classic affordance

When IRC was conceived (1988), the lack of backlogs was not a particularly unique property of IRC - the feature was absent from several other chat devices. However, by the end of the decade – when the population of the Internet exploded – it took on a particular significance. While purveyors of various other services had to look for a business model in order to ensure the sustainability of their operations – IRC operators were not forced to commodify their services. Why?

Because keeping track of backlogs for each user would mean that resource utilisation scaled exponentially with the number of users, whereas if the server only broadcasts new lines as they arrive and then forgets about them, connecting more users results in little overhead. This is more or less true for both processing power and storage capacity: the two essential computing costs to be taken into account when operating services. Similarly, keeping backlogs would increase the complexity of server software, translating into increased costs in terms of development and administration work hours. Thus, the lack of backlogs arguably makes IRC more simple and efficient.

How these factors played out historically was that workers at Internet Service Providers or academic outlets could just let a spare server running in the corner, without having to justify the expenses to funders or answering too many questions from their superiors. Under-the-counter IRC hosting can be thought of as the détournement of fixed capital by users, rather than the recuperation of users’ demands by capital. Again, in the beginning of the decade it was usual practice for the Internet community to run popular services on a volunteer basis, or for institutions to contribute to the running costs of public infrastructures. However, by the end of the decade the dotcom bubble was in full swing and users flooded the networks, so that operating media comparable to the popularity of IRC was serious business.

*“Scaling”* became a buzzword of the era. It referred to the architectural problem of designing technologies that given enough resources could answer an arbitrarily large amount of requests, following the growth of the user base without collapse. The lack of backlogs allowed IRC to keep up with the radical increase of Internet users and *become a mass media of its own*. IRC came to be the most popular dating application before dating websites went online, music sharing software before the rise and fall of Napster, and micro-blogging service before Twitter cashed in on hashtags. Users saw nothing geeky or techie in IRC in the 1990s: it was as commonplace as the ubiquitous GeoCities home pages.

An anecdote illustrates the relationship of IRC to the burgeoning IT industry. It was already 1999 when Microsoft included an IRC client in the default installation of its popular Windows operating system, taking note of IRC’s mainstream appeal. In the first major attempt to recuperate IRC, the software was developed by the company’s Artificial Intelligence research unit, and the application connected automatically to the company’s own IRC servers. Ironically, the Comic Chat IRC interface was never popular with users, and the only artifact that went down in history from the whole enterprise was the Comic Sans font, which is still the laughing stock of Internet users. Microsoft never figured out how to make money from the largest online chat phenomena of the time.

### As a modern affordance

The lack of backlogs came to mean a very different thing in the age of mass surveillance. For instance, take a sticker from the Riseup collective (the largest anarchist/activist email provider) on my laptop. It is advertising their services with the slogan “No Logs, No Masters”. They can disperse with keeping logs because they are based in the United States: in Europe, the implementation of the EU Data Retention Directive requires communication service providers to keep logs. Ironically, IRC is not included in the scope of the legislation, probably thanks to its obscurity. As I explained earlier, surveillance (technically based on the analysis of log files) is not only seen as indispensable for national security, it is also generating the advertisement revenue of companies like Google, accounting for 89% of its profits in 2014 (Griffith 2015).[^2] The kind of digital milieus where average Internet users chit-chat nowadays have been variously described by scholars as *enclosures*, *walled gardens* and *social media monopolies* (Lovink and Rasch 2013).

In contrast, IRC networks are made up of federated servers run by otherwise unconnected actors, from individual geeks through academic institutions to IT companies or even criminal organisations. So much so, that upon logging in to a mainstream IRC network today, it is actually hard to find out who is sponsoring the resources behind the server. The model of Internet-wise, community-run, community-policed and community-developed communication resources may seem atavistic today, when even starry-eyed activists think that it is impossible to change the world without becoming entrepreneurs and finding a “sustainable” business model. However, running the infrastructure as a commons works for IRC just as well as in the 1990s. It allows users to understand and control the media they use to share and collaborate: an essential condition for nurturing *technological sovereignty*.

The late Fidel Castro said that “a revolution is not a bed of roses. A revolution is a struggle between the future and the past.” Here, we could say the past and the present. Like Cuba, despite IRC’s relevant affordances that answer to the burning questions of the day, both are increasingly anachronistic in the context of the contemporary technological and political landscape. Using, maintaining, and developing IRC became increasingly cumbersome: like building a veritable time machine that can bring back techno-political conditions from the past.

The same feature that allowed IRC to become a mass media in the 1990s actually *prevents it from mainstream adoption in the 2010s*. Users dropping into a channel, asking a question, then leaving in frustration 20 minutes later are a case in point. These *lamers* living in the age of mobile connectivity cannot keep their IRC clients logged in for hours on end, like the owners of desktop computers once did, and IRC users who have access to always-on servers do today. Now, only relatively sophisticated users get the full IRC experience, and feel part of the chat channels community. Such elitism excludes less motivated users, but keeps the conversation within the circles of those *“who care about the quality of the material”*:[^3] active members of peer production communities.

## Conclusions

It seems that technical deficiencies can have positive social consequences. The same limitation – the lack of backlogs – that allowed IRC to become a mass media in the 1990s, prevents its mass adoption in the 2010s. However, it also poses problems for data mining and surveillance, which eventually forestalls its recuperation. As a user-controlled technology, it now plays an important part in the media ecology of the Internet, as the everyday backstage communication platform for peer production communities.

These relatively sophisticated user groups benefit from the simplicity, flexibility and open architecture of the medium, which allows them to customise it to their needs. Conversely, most Internet users are used to be served by corporate social media platforms that cater to their needs effortlessly. The contrast between the two approaches to technology adoption begs the question whether it is more desirable to work for the democratisation of knowledge or merely the democratisation of technology.

*The lack of backlogs helped to build technological sovereignity for Internet users for a decade and later sheltered peer producers from the capitalist requirements of exploitation and repression.* Those who care about IRC had to navigate a terrain of changing social conditions – including rifts in the technological landscape and paradigm shifts in political economy – which recontextualised the significance of technical features and limitations. The contemporary use of IRC is based on properties and patterns of the medium that were commonplace in the 1990s but were superseded by more capitalist media since then. Therefore, it can be conceptualised as a *time machine* which brings past technological and political conditions to the present, with surprising consequences.[^4]

## Bibliography

Broughton, John. 2008. *Wikipedia: The Missing Manual*. 1st ed. O’Reilly Media.

Coleman, Gabriella. 2012. *Coding Freedom: The Ethics and Aesthetics of Hacking*. Princeton, NJ: Princeton University Press.

Dagdelen, Demet. 2012. “Anonymous, WikiLeaks and Operation Payback: A Path to Political Action Through IRC and Twitter.” Paper presented at the IPP2012: Big Data, Big Challenges?, Oxford Internet Institute, Oxford, UK. <http://ipp.oii.ox.ac.uk/sites/ipp.oii.ox.ac.uk/files/documents/Dagdelen2.pdf>.

Fuchs, Christian. 2012. “Google Capitalism.” *TripleC: Cognition, Communication, Co-Operation* 10 (1): 42–48.

Gillespie, Tarleton. 2010. “The Politics of ‘Platforms’.” *New Media & Society* 12 (3): 347–364. doi:[10.1177/1461444809342738](http://dx.doi.org/10.1177/1461444809342738).

Griffith, Erin. 2015. “Bad News for Google Parent Alphabet: The ‘G’ Will Still Foot the Bill.” Article in Forbes Magazine. <http://fortune.com/2015/08/10/google-ads-money/>.

Haché, Alex. 2014. “Technological Sovereignty.” *Passarelle* 11 (11): 165–171. <http://www.coredem.info/rubrique48.html>.

Ippolita. 2015. *The Facebook Aquarium: The Resistible Rise of Anarcho-Capitalism*. Revised and updated English edition. Theory on Demand 15. Amsterdam: Institute for Network Cultures. <http://networkcultures.org/blog/publication/no-15-in-the-facebook-aquarium-the-resistible-rise-of-anarcho-capitalism-ippolita/>.

Latzko-Toth, Guillaume. 2010. “Metaphors of Synchrony: Emergence Differentiation of Online Chat Devices.” *Bulletin of Science, Technology & Society* 30 (5): 362–374. doi:[10.1177/0270467610380005](http://dx.doi.org/10.1177/0270467610380005). <http://bst.sagepub.com/content/30/5/362.short>.

Levy, Steven. 1984. *Hackers: Heroes of the Computer Revolution*. Anchor Press, Doubleday.

Lovink, Geert, and Miriam Rasch. 2013. *Unlike Us Reader: Social Media Monopolies and Their Alternatives*. INC Reader \#8. Institute of Network Cultures. <http://gen.lib.rus.ec/book/index.php?md5=C5785D014EFDDBB415354677C0FF7A8A>.

Maxigas. 2014. “History of Real Time Chat Protocols.” *Relay\#70 Panel F* (February). <http://relay70.metatron.ai/history-of-real-time-chat-protocols.html>.

———. 2015. “Peer Production of Open Hardware: Unfinished Artefacts and Architectures in the Hackerspaces.” PhD thesis, Barcelona: Universitat Oberta de Catalunya, Internet Interdisciplinary Institute. <https://research.metatron.ai/maxigas_dissertation.pdf>.

Stalder, Felix. 2013. “Between Democracy and Spectacle: The Front and the Back of the Social Web.” In *Unlike Us Reader: Social Media Monopolies and Their Alternatives*, ed. Geert Lovink and Miriam Rasch. INC Reader \#8. Amsterdam: Institute of Network Cultures. <http://felix.openflows.com/node/223>.

[^1]: *“The legacy of the 20th century has accustomed us to think that social control pertains only to the political, but it has long since become primarily an economic question of commercial implications. It is no coincidence that the NSA has made use of the collaboration with Microsoft, Yahoo, Google, Facebook, Apple and so on, to obtain data for the surveillance program PRISM.”* (Ippolita 2015, 7)

[^2]: *“Google is a profit-oriented, advertising-financed moneymaking machine that turns users and their data into a commodity.”* (Fuchs 2012, 47)

[^3]: A reference to organised crime syndicates in the Black Lagoon anime series.

[^4]: With the support of a postdoctoral grant from the Universitat Oberta de Catalunya (UOC) and the sponsorship of the Central European University Foundation, Budapest (CEUBPF) for a fellowship at the Center for Media, Data and Society in the School of Public Policy.
